@@ -23,36 +23,34 @@ from cmd2 import (
     with_argparser,
 )
 
-DC_TOOLS = [ 'system-tools', 'dev-tools', 'app-services','dataset-services','dl-model-services','dl-model-training-services',
+DC_TOOLS = [ 'system-tools','app-services','dataset-services','dl-model-services','dl-model-training-services',
                 'dlstreamer-pipeline-services','edge-deployment-services','edge-inference-app-services',
                 'edge-to-cloud-app-services','k8s-services','intel-dev-tools','oneapi-toolkits','one-edge-building-blocks',
-                'cloud-native-tools']
+                'developer-tools']
 DC_COMMANDS = ['install', 'uninstall']
 DC_COMMANDS_WE = ['install', 'uninstall', 'enable', 'disable']
 APP_COMMANDS = ['start', 'stop', 'restart']
 
 SUB_TOOLS={
   "system-tools":['sftp', 'ssh', 'vnc', 'no-machine','vim'],
-  "dev-tools":['code-editor-tools','container-runtimes'],
+  "developer-tools":['code-editor-tools','container-runtimes','automation-and-configuration','infrastructure-as-code','continous-integration','continous-deployment'],
   "app-services":['system-telemetry','cluster-telemetry','docker-telemetry','log-analytics'],  
   "dataset-services":['intel','partner','public','synthetic'],
-  "dl-model-services":['dl-model-tools', 'inference-runtimes','featured-dl-models'],
+  "dl-model-services":['dl-model-tools', 'inference-runtimes','featured-dl-models','openvino-samples-and-demos'],
   "dl-model-training-services":['data-engineering-tools', 'datasets', 'model-zoo', 'training-frameworks','ai-reference-kits'],
   "dlstreamer-pipeline-services":['audio-pipelines','dlstreamer-tools','multi-sensory-pipelines','video-pipelines'],
   "edge-deployment-services":['cross-plane','health-check','mass','vpshere-vm'],
   "edge-inference-app-services":['healthcare','industrial','market-places','media','retail','safety-security','transportation'],
   "edge-to-cloud-app-services":['seo-samples','seo-reference-implementations','seo-3rd-party-applications'],
-  "k8s-services":['aether','kind','kubespray','microk8s','kubeadm','minikube','openshift','rancher-k3s','rancher-rke2','smart-edge-open','starlingx','tanzu'],
+  "k8s-services":['aether','kind','microk8s','kubeadm','minikube','rancher-k3s','rancher-rke2'],
   "intel-dev-tools":['intel-auto-deploy','intel-auto-test','intel-code-scans','mgt-console'],
   "oneapi-toolkits":['ai-analytics-toolkit','base-toolkit','intel-vtune','iot-toolkit','scikit-learn','xgboost'],
-  "one-edge-building-blocks":['csp-services','inference-services','observability-services'],
-  "cloud-native-tools" :['automation-tools','cd-tools','ci-tools','iac-tools','observability-tools']
+  "one-edge-building-blocks":['csp-services','inference-services','observability-services']
 }
 
 TOOLS={
   "code-editor-tools":['jupyter-notebook','jupyter-lab','atom','sublime-text','notepad++','vscode'],
   "container-runtimes":['docker', 'docker-compose','containerd','cri-o'], 
-  "automation-and-configuration-tools":['ansible','chef','puppet'],
   "dl-model-tools":['dl-model-benchmark', 'nncf', 'omz-tools', 'openvino-dl-workbench','openvino-model-server', 
                     'post-training-optimization-toolkit'],
   "inference-runtimes":['intel-optimized-pytorch', 'intel-optimized-tensorflow','onnx', 'openvino-2022.1', 'openvino-addon-tensorflow'],
@@ -81,7 +79,10 @@ TOOLS={
   "csp-services":['aws-greengrass','azure-iot-central','azure-iot-edge','azure-iot-hub'],
   "inference-services":['dlstreamer','dlstreamer-pipeline-server','openvino-container','openvino-model-server'],
   "observability-services":['system-telemetry','cluster-telemetry','docker-telemetry','log-analytics'],
-  "automation-tools":['ansible','chef','puppet'] 
+  "automation-and-configuration":['ansible','chef','puppet'], 
+  "infrastructure-as-code":['terraform','pulumi','cross-plane'],
+  "continous-integration":['github-actions','tekton','jenkins'],
+  "continous-deployment":['jenkins-X','argocd']
 
 }
 
